@@ -1,3 +1,5 @@
+from pathlib import Path
+
 import django
 
 from .entities import Guest
@@ -5,6 +7,7 @@ from .entities import Guest
 
 def pytest_configure():
     from django.conf import settings
+    app_dir = Path(__file__)
     settings.configure(
         ROOT_URLCONF='tests.urls',
         REST_FRAMEWORK={
@@ -14,6 +17,7 @@ def pytest_configure():
         TEMPLATES=[
             {
                 'BACKEND': 'django.template.backends.django.DjangoTemplates',
+                'DIRS': [app_dir.parent.name + '/templates'],
                 'APP_DIRS': True,
                 'OPTIONS': {
                     'debug': True,  # We want template errors to raise
@@ -25,5 +29,3 @@ def pytest_configure():
         ),
     )
     django.setup()
-    import winter_openapi
-    winter_openapi.setup()
