@@ -3,5 +3,3 @@ from .domain_event import DomainEvent
 from .domain_event_handler import domain_event_handler
 from .domain_event_handler import global_domain_event_dispatcher
 from .domain_events import DomainEvents
-from .entity import Entity
-from .value_object import ValueObject
